Utilities functions
===================

Body Surface Area
-----------------

The body surface area (BSA) is the measured or calculated surface of a human body. It is used as a reference for the estimation of the metabolic rate of an individual. The BSA is usually measured in square meters. The most common formula to calculate the BSA is the Du Bois formula, which is based on the height and weight of the individual. All the equations implemented in pythermalcomfort are contained in pythermalcomfort.utilities.BodySurfaceAreaEquations

.. autofunction:: pythermalcomfort.utilities.body_surface_area

Dew point temperature
---------------------

.. autofunction:: pythermalcomfort.utilities.dew_point_tmp

Enthalpy
--------

.. autofunction:: pythermalcomfort.utilities.enthalpy_air

Mean radiant temperature
------------------------

.. autofunction:: pythermalcomfort.utilities.mean_radiant_tmp

Operative temperature
---------------------

.. autofunction:: pythermalcomfort.utilities.operative_tmp

Psychrometric properties of air from dry-bulb temperature and relative humidity
-------------------------------------------------------------------------------

.. autofunction:: pythermalcomfort.utilities.psy_ta_rh

Relative air speed
------------------

.. autofunction:: pythermalcomfort.utilities.v_relative

Running mean outdoor temperature
--------------------------------

.. autofunction:: pythermalcomfort.utilities.running_mean_outdoor_temperature

Saturation vapor pressure
-------------------------

.. autofunction:: pythermalcomfort.utilities.p_sat

Sky-vault view fraction
-----------------------

.. autofunction:: pythermalcomfort.utilities.f_svv

Units converter
---------------

.. autofunction:: pythermalcomfort.utilities.units_converter

Wet bulb temperature
--------------------

.. autofunction:: pythermalcomfort.utilities.wet_bulb_tmp
